@@ -1,24 +1,23 @@
-#[allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
 use error_chain::bail;
+#[allow(unused_imports)]
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 
-use crate::plugin::*;
 use crate::error::*;
 use crate::event::*;
 use crate::index::*;
-use crate::validator::*;
+use crate::plugin::*;
 use crate::transaction::*;
+use crate::validator::*;
 
 use std::sync::Arc;
 
-use crate::spec::*;
 use crate::lint::*;
-use crate::transform::*;
 use crate::service::*;
 use crate::session::AteSession;
+use crate::spec::*;
+use crate::transform::*;
 
-pub(crate) struct ChainProtectedSync
-{
+pub(crate) struct ChainProtectedSync {
     pub(crate) integrity: TrustMode,
     pub(crate) default_session: Box<dyn AteSession>,
     pub(crate) sniffers: Vec<ChainSniffer>,
@@ -30,11 +29,13 @@ pub(crate) struct ChainProtectedSync
     pub(crate) services: Vec<Arc<dyn Service>>,
 }
 
-impl ChainProtectedSync
-{
+impl ChainProtectedSync {
     #[allow(dead_code)]
-    pub(super) fn validate_event(&self, header: &EventHeader, conversation: Option<&Arc<ConversationSession>>) -> Result<ValidationResult, ValidationError>
-    {
+    pub(super) fn validate_event(
+        &self,
+        header: &EventHeader,
+        conversation: Option<&Arc<ConversationSession>>,
+    ) -> Result<ValidationResult, ValidationError> {
         let mut deny_reason = String::default();
         let mut is_deny = false;
         let mut is_allow = false;
@@ -42,33 +43,45 @@ impl ChainProtectedSync
         for validator in self.validators.iter() {
             match validator.validate(header, conversation) {
                 Ok(ValidationResult::Deny) => {
-                    if deny_reason.is_empty() == false { deny_reason.push_str(" + "); };
-                    deny_reason.push_str(format!("denied by validator({})", validator.validator_name()).as_str());
+                    if deny_reason.is_empty() == false {
+                        deny_reason.push_str(" + ");
+                    };
+                    deny_reason.push_str(
+                        format!("denied by validator({})", validator.validator_name()).as_str(),
+                    );
                     is_deny = true
-                },
+                }
                 Ok(ValidationResult::Allow) => is_allow = true,
-                Ok(ValidationResult::Abstain) => { },
+                Ok(ValidationResult::Abstain) => {}
                 Err(ValidationError(ValidationErrorKind::Denied(reason), _)) => {
-                    if deny_reason.is_empty() == false { deny_reason.push_str(" + "); };
+                    if deny_reason.is_empty() == false {
+                        deny_reason.push_str(" + ");
+                    };
                     deny_reason.push_str(reason.as_str());
                     is_deny = true
-                },
+                }
                 Err(ValidationError(ValidationErrorKind::Detached, _)) => is_deny = true,
-                Err(ValidationError(ValidationErrorKind::AllAbstained, _)) => { },
+                Err(ValidationError(ValidationErrorKind::AllAbstained, _)) => {}
                 Err(ValidationError(ValidationErrorKind::NoSignatures, _)) => {
-                    if deny_reason.is_empty() == false { deny_reason.push_str(" + "); };
+                    if deny_reason.is_empty() == false {
+                        deny_reason.push_str(" + ");
+                    };
                     deny_reason.push_str("no signatures");
                     is_deny = true
-                },
+                }
                 Err(ValidationError(ValidationErrorKind::Many(errors), _)) => {
                     for err in errors {
-                        if deny_reason.is_empty() == false { deny_reason.push_str(" + "); };
+                        if deny_reason.is_empty() == false {
+                            deny_reason.push_str(" + ");
+                        };
                         deny_reason.push_str(err.to_string().as_str());
                         is_deny = true
                     }
-                },
+                }
                 Err(err) => {
-                    if deny_reason.is_empty() == false { deny_reason.push_str(" + "); };
+                    if deny_reason.is_empty() == false {
+                        deny_reason.push_str(" + ");
+                    };
                     deny_reason.push_str(err.to_string().as_str());
                     is_deny = true
                 }
@@ -77,33 +90,45 @@ impl ChainProtectedSync
         for plugin in self.plugins.iter() {
             match plugin.validate(header, conversation) {
                 Ok(ValidationResult::Deny) => {
-                    if deny_reason.is_empty() == false { deny_reason.push_str(" + "); };
-                    deny_reason.push_str(format!("denied by validator({})", plugin.validator_name()).as_str());
+                    if deny_reason.is_empty() == false {
+                        deny_reason.push_str(" + ");
+                    };
+                    deny_reason.push_str(
+                        format!("denied by validator({})", plugin.validator_name()).as_str(),
+                    );
                     is_deny = true
-                },
+                }
                 Ok(ValidationResult::Allow) => is_allow = true,
-                Ok(ValidationResult::Abstain) => { },
+                Ok(ValidationResult::Abstain) => {}
                 Err(ValidationError(ValidationErrorKind::Denied(reason), _)) => {
-                    if deny_reason.is_empty() == false { deny_reason.push_str(" + "); };
+                    if deny_reason.is_empty() == false {
+                        deny_reason.push_str(" + ");
+                    };
                     deny_reason.push_str(reason.as_str());
                     is_deny = true
-                },
+                }
                 Err(ValidationError(ValidationErrorKind::Detached, _)) => is_deny = true,
-                Err(ValidationError(ValidationErrorKind::AllAbstained, _)) => { },
+                Err(ValidationError(ValidationErrorKind::AllAbstained, _)) => {}
                 Err(ValidationError(ValidationErrorKind::NoSignatures, _)) => {
-                    if deny_reason.is_empty() == false { deny_reason.push_str(" + "); };
+                    if deny_reason.is_empty() == false {
+                        deny_reason.push_str(" + ");
+                    };
                     deny_reason.push_str("no signatures");
                     is_deny = true
-                },
+                }
                 Err(ValidationError(ValidationErrorKind::Many(errors), _)) => {
                     for err in errors {
-                        if deny_reason.is_empty() == false { deny_reason.push_str(" + "); };
+                        if deny_reason.is_empty() == false {
+                            deny_reason.push_str(" + ");
+                        };
                         deny_reason.push_str(err.to_string().as_str());
                         is_deny = true
                     }
-                },
+                }
                 Err(err) => {
-                    if deny_reason.is_empty() == false { deny_reason.push_str(" + "); };
+                    if deny_reason.is_empty() == false {
+                        deny_reason.push_str(" + ");
+                    };
                     deny_reason.push_str(err.to_string().as_str());
                     is_deny = true
                 }
@@ -119,8 +144,7 @@ impl ChainProtectedSync
         Ok(ValidationResult::Allow)
     }
 
-    pub fn set_integrity_mode(&mut self, mode: TrustMode)
-    {
+    pub fn set_integrity_mode(&mut self, mode: TrustMode) {
         debug!("switching to {}", mode);
 
         self.integrity = mode;
@@ -131,4 +155,4 @@ impl ChainProtectedSync
             val.set_integrity_mode(mode);
         }
     }
-}
\ No newline at end of file
+}
