@@ -1,8 +1,7 @@
 #[derive(Debug, Clone, Default)]
-pub struct Metrics
-{
+pub struct Metrics {
     pub received: u64,
     pub sent: u64,
     pub requests: u64,
     pub chain_size: u64,
-}
\ No newline at end of file
+}
