@@ -1,11 +1,17 @@
 #![allow(unused_imports)]
+use crate::crypto::InitializationVector;
 use crate::engine::timeout as tokio_timeout;
+use bytes::BytesMut;
 use error_chain::bail;
+use std::collections::VecDeque;
 use std::fs::File;
+use std::net::SocketAddr;
 use std::result::Result;
 use std::str::FromStr;
 use std::sync::Arc;
 use std::time::Duration;
+use std::io::Error as TError;
+use std::io::ErrorKind as TErrorKind;
 #[cfg(feature = "enable_full")]
 use tokio::net::tcp::OwnedReadHalf;
 #[cfg(feature = "enable_full")]
@@ -14,12 +20,10 @@ use tokio::net::tcp::OwnedWriteHalf;
 use tokio::net::TcpStream;
 use tokio::sync::mpsc;
 use tracing::{debug, error, info, instrument, span, trace, warn, Level};
-#[cfg(target_arch = "wasm32")]
 use wasm_bus_ws::prelude::RecvHalf as WasmRecvHalf;
-#[cfg(target_arch = "wasm32")]
 use wasm_bus_ws::prelude::SendHalf as WasmSendHalf;
-#[cfg(target_arch = "wasm32")]
 use wasm_bus_ws::prelude::WebSocket as WasmWebSocket;
+use bytes::Bytes;
 
 use crate::comms::PacketData;
 use crate::crypto::EncryptKey;
@@ -40,10 +44,14 @@ use {
 
 use crate::error::*;
 
+use super::NodeId;
+use super::protocol::MessageProtocolApi;
+
 #[derive(Debug, Clone, Copy)]
 pub enum StreamProtocol {
     Tcp,
     WebSocket,
+    SecureWebSocket,
 }
 
 impl std::str::FromStr for StreamProtocol {
@@ -53,6 +61,7 @@ impl std::str::FromStr for StreamProtocol {
         let ret = match s {
             "tcp" => StreamProtocol::Tcp,
             "ws" => StreamProtocol::WebSocket,
+            "wss" => StreamProtocol::SecureWebSocket,
             _ => {
                 bail!(CommsErrorKind::UnsupportedProtocolError(s.to_string()));
             }
@@ -66,6 +75,7 @@ impl StreamProtocol {
         let ret = match self {
             StreamProtocol::Tcp => "tcp",
             StreamProtocol::WebSocket => "ws",
+            StreamProtocol::SecureWebSocket => "wss",
         };
         ret.to_string()
     }
@@ -78,6 +88,7 @@ impl StreamProtocol {
         match self {
             StreamProtocol::Tcp => 5000,
             StreamProtocol::WebSocket => 80,
+            StreamProtocol::SecureWebSocket => 443,
         }
     }
 
@@ -85,6 +96,7 @@ impl StreamProtocol {
         match self {
             StreamProtocol::Tcp => true,
             StreamProtocol::WebSocket => false,
+            StreamProtocol::SecureWebSocket => false,
         }
     }
 
@@ -92,6 +104,7 @@ impl StreamProtocol {
         match self {
             StreamProtocol::Tcp => false,
             StreamProtocol::WebSocket => true,
+            StreamProtocol::SecureWebSocket => true,
         }
     }
 }
@@ -128,7 +141,6 @@ pub enum Stream {
         StreamProtocol,
     ),
     ViaFile(std::fs::File, StreamProtocol),
-    #[cfg(target_arch = "wasm32")]
     WasmWebSocket(WasmWebSocket),
 }
 
@@ -160,76 +172,161 @@ impl StreamProtocol {
 }
 
 #[derive(Debug)]
-pub enum StreamRx {
+pub struct StreamRx {
+    inner: StreamRxInner,
+    protocol: StreamProtocol,
+    version: Box<dyn MessageProtocolApi + 'static>,
+}
+
+#[derive(Debug)]
+pub enum StreamRxInner {
     #[cfg(feature = "enable_full")]
     Tcp(OwnedReadHalf),
     #[cfg(feature = "enable_full")]
     WebSocket(futures_util::stream::SplitStream<WebSocketStream<TcpStream>>),
     #[cfg(feature = "enable_server")]
     HyperWebSocket(futures_util::stream::SplitStream<HyperWebSocket<HyperUpgraded>>),
-    ViaStream(
-        Arc<tokio::sync::Mutex<Box<dyn AsyncStream + 'static>>>,
-        StreamProtocol,
-    ),
-    ViaQueue(mpsc::Receiver<Vec<u8>>, StreamProtocol),
-    ViaFile(Arc<std::sync::Mutex<std::fs::File>>, StreamProtocol),
-    #[cfg(target_arch = "wasm32")]
+    ViaStream(Arc<tokio::sync::Mutex<Box<dyn AsyncStream + 'static>>>),
+    ViaQueue(mpsc::Receiver<Vec<u8>>),
+    ViaFile(Arc<std::sync::Mutex<std::fs::File>>),
     WasmWebSocket(WasmRecvHalf),
 }
 
+#[cfg(feature = "enable_full")]
+impl From<OwnedReadHalf>
+for StreamRx
+{
+    fn from(inner: OwnedReadHalf) -> Self {
+        Self::new(StreamRxInner::Tcp(inner), StreamProtocol::Tcp)
+    }
+}
+
+#[cfg(feature = "enable_full")]
+impl From<futures_util::stream::SplitStream<WebSocketStream<TcpStream>>>
+for StreamRx
+{
+    fn from(inner: futures_util::stream::SplitStream<WebSocketStream<TcpStream>>) -> Self {
+        Self::new(StreamRxInner::WebSocket(inner), StreamProtocol::WebSocket)
+    }
+}
+
+#[cfg(feature = "enable_server")]
+impl From<futures_util::stream::SplitStream<HyperWebSocket<HyperUpgraded>>>
+for StreamRx
+{
+    fn from(inner: futures_util::stream::SplitStream<HyperWebSocket<HyperUpgraded>>) -> Self {
+        Self::new(StreamRxInner::HyperWebSocket(inner), StreamProtocol::WebSocket)
+    }
+}
+
+impl From<WasmRecvHalf>
+for StreamRx
+{
+    fn from(inner: WasmRecvHalf) -> Self {
+        Self::new(StreamRxInner::WasmWebSocket(inner), StreamProtocol::WebSocket)
+    }
+}
+
 #[derive(Debug)]
-pub enum StreamTx {
+pub struct StreamTx {
+    inner: StreamTxInner,
+    #[allow(dead_code)]
+    protocol: StreamProtocol,
+    version: Box<dyn MessageProtocolApi + 'static>,
+}
+
+#[derive(Debug)]
+pub enum StreamTxInner {
     #[cfg(feature = "enable_full")]
     Tcp(OwnedWriteHalf),
     #[cfg(feature = "enable_full")]
     WebSocket(futures_util::stream::SplitSink<WebSocketStream<TcpStream>, Message>),
     #[cfg(feature = "enable_server")]
     HyperWebSocket(futures_util::stream::SplitSink<HyperWebSocket<HyperUpgraded>, HyperMessage>),
-    ViaStream(
-        Arc<tokio::sync::Mutex<Box<dyn AsyncStream + 'static>>>,
-        StreamProtocol,
-    ),
-    ViaQueue(mpsc::Sender<Vec<u8>>, StreamProtocol),
-    ViaFile(Arc<std::sync::Mutex<std::fs::File>>, StreamProtocol),
-    #[cfg(target_arch = "wasm32")]
+    ViaStream(Arc<tokio::sync::Mutex<Box<dyn AsyncStream + 'static>>>),
+    ViaQueue(mpsc::Sender<Vec<u8>>),
+    ViaFile(Arc<std::sync::Mutex<std::fs::File>>),
     WasmWebSocket(WasmSendHalf),
 }
 
+#[cfg(feature = "enable_full")]
+impl From<OwnedWriteHalf>
+for StreamTx
+{
+    fn from(inner: OwnedWriteHalf) -> Self {
+        Self::new(StreamTxInner::Tcp(inner), StreamProtocol::Tcp)
+    }
+}
+
+#[cfg(feature = "enable_full")]
+impl From<futures_util::stream::SplitSink<WebSocketStream<TcpStream>, Message>>
+for StreamTx
+{
+    fn from(inner: futures_util::stream::SplitSink<WebSocketStream<TcpStream>, Message>) -> Self {
+        Self::new(StreamTxInner::WebSocket(inner), StreamProtocol::WebSocket)
+    }
+}
+
+#[cfg(feature = "enable_server")]
+impl From<futures_util::stream::SplitSink<HyperWebSocket<HyperUpgraded>, HyperMessage>>
+for StreamTx
+{
+    fn from(inner: futures_util::stream::SplitSink<HyperWebSocket<HyperUpgraded>, HyperMessage>) -> Self {
+        Self::new(StreamTxInner::HyperWebSocket(inner), StreamProtocol::WebSocket)
+    }
+}
+
+impl From<WasmSendHalf>
+for StreamTx
+{
+    fn from(inner: WasmSendHalf) -> Self {
+        Self::new(StreamTxInner::WasmWebSocket(inner), StreamProtocol::WebSocket)
+    }
+}
+
 impl Stream {
     pub fn split(self) -> (StreamRx, StreamTx) {
         match self {
             #[cfg(feature = "enable_full")]
             Stream::Tcp(a) => {
                 let (rx, tx) = a.into_split();
-                (StreamRx::Tcp(rx), StreamTx::Tcp(tx))
+                (StreamRx::new(StreamRxInner::Tcp(rx), StreamProtocol::Tcp),
+                 StreamTx::new(StreamTxInner::Tcp(tx), StreamProtocol::Tcp))
             }
             #[cfg(feature = "enable_full")]
-            Stream::WebSocket(a, _) => {
+            Stream::WebSocket(a, p) => {
                 use futures_util::StreamExt;
                 let (tx, rx) = a.split();
-                (StreamRx::WebSocket(rx), StreamTx::WebSocket(tx))
+                (StreamRx::new(StreamRxInner::WebSocket(rx), p),
+                 StreamTx::new(StreamTxInner::WebSocket(tx), p))
             }
             #[cfg(feature = "enable_server")]
-            Stream::HyperWebSocket(a, _) => {
+            Stream::HyperWebSocket(a, p) => {
                 use futures_util::StreamExt;
                 let (tx, rx) = a.split();
-                (StreamRx::HyperWebSocket(rx), StreamTx::HyperWebSocket(tx))
+                (StreamRx::new(StreamRxInner::HyperWebSocket(rx), p),
+                 StreamTx::new(StreamTxInner::HyperWebSocket(tx), p))
             }
             Stream::ViaStream(a, p) => {
                 let a = Arc::new(tokio::sync::Mutex::new(a));
                 let b = Arc::clone(&a);
-                (StreamRx::ViaStream(a, p), StreamTx::ViaStream(b, p))
+                (StreamRx::new(StreamRxInner::ViaStream(a), p),
+                 StreamTx::new(StreamTxInner::ViaStream(b), p))
             }
-            Stream::ViaQueue(a, b, p) => (StreamRx::ViaQueue(b, p), StreamTx::ViaQueue(a, p)),
+            Stream::ViaQueue(a, b, p) => {
+                (StreamRx::new(StreamRxInner::ViaQueue(b), p),
+                 StreamTx::new(StreamTxInner::ViaQueue(a), p))
+            },
             Stream::ViaFile(a, p) => {
                 let rx = Arc::new(std::sync::Mutex::new(a));
                 let tx = Arc::clone(&rx);
-                (StreamRx::ViaFile(rx, p), StreamTx::ViaFile(tx, p))
+                (StreamRx::new(StreamRxInner::ViaFile(rx), p),
+                 StreamTx::new(StreamTxInner::ViaFile(tx), p))
             }
-            #[cfg(target_arch = "wasm32")]
             Stream::WasmWebSocket(a) => {
                 let (tx, rx) = a.split();
-                (StreamRx::WasmWebSocket(rx), StreamTx::WasmWebSocket(tx))
+                (StreamRx::new(StreamRxInner::WasmWebSocket(rx), StreamProtocol::WebSocket),
+                 StreamTx::new(StreamTxInner::WasmWebSocket(tx), StreamProtocol::WebSocket))
             }
         }
     }
@@ -246,7 +343,7 @@ impl Stream {
             #[cfg(feature = "enable_full")]
             Stream::Tcp(a) => match protocol {
                 StreamProtocol::Tcp => Stream::Tcp(a),
-                StreamProtocol::WebSocket => {
+                StreamProtocol::WebSocket | StreamProtocol::SecureWebSocket => {
                     let wait = tokio_tungstenite::accept_async(a);
                     let socket = tokio_timeout(timeout, wait).await??;
                     Stream::WebSocket(socket, protocol)
@@ -259,7 +356,6 @@ impl Stream {
             Stream::ViaStream(a, p) => Stream::ViaStream(a, p),
             Stream::ViaQueue(a, b, p) => Stream::ViaQueue(a, b, p),
             Stream::ViaFile(a, p) => Stream::ViaFile(a, p),
-            #[cfg(target_arch = "wasm32")]
             Stream::WasmWebSocket(a) => Stream::WasmWebSocket(a),
         };
 
@@ -275,10 +371,14 @@ impl Stream {
             #[cfg(feature = "enable_full")]
             Stream::Tcp(a) => match protocol {
                 StreamProtocol::Tcp => Stream::Tcp(a),
-                StreamProtocol::WebSocket => {
+                StreamProtocol::WebSocket | StreamProtocol::SecureWebSocket => {
+                    let port = match protocol {
+                        StreamProtocol::SecureWebSocket => 443,
+                        _ => 80
+                    };
                     let url = StreamProtocol::WebSocket.make_url(
                         "localhost".to_string(),
-                        80,
+                        port,
                         "/".to_string(),
                     )?;
                     let mut request = tokio_tungstenite::tungstenite::http::Request::new(());
@@ -301,7 +401,6 @@ impl Stream {
             Stream::ViaStream(a, p) => Stream::ViaStream(a, p),
             Stream::ViaQueue(a, b, p) => Stream::ViaQueue(a, b, p),
             Stream::ViaFile(a, p) => Stream::ViaFile(a, p),
-            #[cfg(target_arch = "wasm32")]
             Stream::WasmWebSocket(a) => Stream::WasmWebSocket(a),
         };
         Ok(ret)
@@ -319,147 +418,125 @@ impl Stream {
             Stream::ViaStream(_, p) => p.clone(),
             Stream::ViaQueue(_, _, p) => p.clone(),
             Stream::ViaFile(_, p) => p.clone(),
-            #[cfg(target_arch = "wasm32")]
             Stream::WasmWebSocket(_) => StreamProtocol::WebSocket,
         }
     }
 }
 
 impl StreamTx {
-    #[allow(unused_variables)]
-    pub async fn write_8bit(
+    pub fn new(inner: StreamTxInner, proto: StreamProtocol) -> Self {
+        Self {
+            inner,
+            protocol: proto,
+            version: Box::new(super::protocol::v1::MessageProtocol::default()),
+        }
+    }
+
+    pub fn change_protocol_version(&mut self, version: Box<dyn MessageProtocolApi + 'static>) {
+        self.version = version;
+    }
+
+    pub async fn close(
+        &mut self
+    ) -> Result<(), tokio::io::Error>
+    {
+        let _ = self.version.send_close(&mut self.inner).await;
+        self.inner.close().await
+    }
+
+    pub async fn write_with_fixed_16bit_header(
         &mut self,
         buf: &'_ [u8],
         delay_flush: bool,
     ) -> Result<u64, tokio::io::Error> {
-        #[allow(unused_mut)]
-        let mut total_sent = 0u64;
-        match self {
-            #[cfg(feature = "enable_full")]
-            StreamTx::Tcp(a) => {
-                if buf.len() > u8::MAX as usize {
-                    return Err(tokio::io::Error::new(
-                        tokio::io::ErrorKind::InvalidData,
-                        format!(
-                            "Data is to big to write (len={}, max={})",
-                            buf.len(),
-                            u8::MAX
-                        ),
-                    ));
-                }
-                a.write_u8(buf.len() as u8).await?;
-                total_sent += 1u64;
-                a.write_all(&buf[..]).await?;
-                total_sent += buf.len() as u64;
-            }
-            #[cfg(feature = "enable_full")]
-            StreamTx::WebSocket(_) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-            #[cfg(feature = "enable_server")]
-            StreamTx::HyperWebSocket(_) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-            StreamTx::ViaStream(_, _) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-            StreamTx::ViaQueue(_, _) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-            StreamTx::ViaFile(_, _) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-            #[cfg(target_arch = "wasm32")]
-            StreamTx::WasmWebSocket(_) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-        }
-        #[allow(unreachable_code)]
-        Ok(total_sent)
+        self.version.write_with_fixed_16bit_header(&mut self.inner, buf, delay_flush).await
     }
 
     #[allow(unused_variables)]
-    pub async fn write_16bit(
+    pub async fn write_with_fixed_32bit_header(
         &mut self,
         buf: &'_ [u8],
         delay_flush: bool,
     ) -> Result<u64, tokio::io::Error> {
-        #[allow(unused_mut)]
-        let mut total_sent = 0u64;
-        match self {
-            #[cfg(feature = "enable_full")]
-            StreamTx::Tcp(a) => {
-                if buf.len() > u16::MAX as usize {
-                    return Err(tokio::io::Error::new(
-                        tokio::io::ErrorKind::InvalidData,
-                        format!(
-                            "Data is to big to write (len={}, max={})",
-                            buf.len(),
-                            u16::MAX
-                        ),
-                    ));
-                }
-                a.write_u16(buf.len() as u16).await?;
-                total_sent += 2u64;
-                a.write_all(&buf[..]).await?;
-                total_sent += buf.len() as u64;
-            }
-            #[cfg(feature = "enable_full")]
-            StreamTx::WebSocket(_) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-            #[cfg(feature = "enable_server")]
-            StreamTx::HyperWebSocket(_) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-            StreamTx::ViaStream(_, _) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-            StreamTx::ViaQueue(_, _) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-            StreamTx::ViaFile(_, _) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-            #[cfg(target_arch = "wasm32")]
-            StreamTx::WasmWebSocket(_) => {
-                total_sent += self.write_32bit(buf, delay_flush).await?;
-            }
-        }
-        #[allow(unreachable_code)]
-        Ok(total_sent)
+        self.version.write_with_fixed_32bit_header(&mut self.inner, buf, delay_flush).await
     }
 
-    #[allow(unused_variables)]
-    pub async fn write_32bit(
+    #[cfg(feature = "enable_server")]
+    fn conv_error_kind(err: &HyperError) -> tokio::io::ErrorKind {
+        match err {
+            HyperError::AlreadyClosed => tokio::io::ErrorKind::ConnectionAborted,
+            HyperError::ConnectionClosed => tokio::io::ErrorKind::ConnectionAborted,
+            HyperError::Io(io) => io.kind(),
+            _ => tokio::io::ErrorKind::Other,
+        }
+    }
+
+    pub async fn send(
         &mut self,
-        buf: &'_ [u8],
-        delay_flush: bool,
+        wire_encryption: &Option<EncryptKey>,
+        data: &[u8],
     ) -> Result<u64, tokio::io::Error> {
-        #[allow(unused_mut)]
-        let mut total_sent = 0u64;
+        self.version.send(&mut self.inner, wire_encryption, data).await
+    }
+}
+
+impl StreamTxInner {
+    pub async fn close(
+        &mut self
+    ) -> Result<(), tokio::io::Error>
+    {
         match self {
             #[cfg(feature = "enable_full")]
-            StreamTx::Tcp(a) => {
-                if buf.len() > u32::MAX as usize {
-                    return Err(tokio::io::Error::new(
-                        tokio::io::ErrorKind::InvalidData,
-                        format!(
-                            "Data is to big to write (len={}, max={})",
-                            buf.len(),
-                            u32::MAX
-                        ),
-                    ));
-                }
-                a.write_u32(buf.len() as u32).await?;
-                total_sent += 4u64;
-                a.write_all(&buf[..]).await?;
-                total_sent += buf.len() as u64;
+            StreamTxInner::Tcp(a) => {
+                let _ = a.flush().await;
+                a.shutdown().await?;
             }
             #[cfg(feature = "enable_full")]
-            StreamTx::WebSocket(a) => {
+            StreamTxInner::WebSocket(a) => {
+                use futures_util::SinkExt;
+                let _ = a.flush().await;
+                a.close().await
+                    .map_err(|err| tokio::io::Error::new(tokio::io::ErrorKind::Other, err))?;
+            }
+            #[cfg(feature = "enable_server")]
+            StreamTxInner::HyperWebSocket(a) => {
+                use futures_util::SinkExt;
+                let _ = a.flush().await;
+                a.close().await
+                    .map_err(|err| tokio::io::Error::new(tokio::io::ErrorKind::Other, err))?;
+            }
+            StreamTxInner::ViaStream(a) => {
+                use tokio::io::AsyncWriteExt;
+                let mut a = a.lock().await;
+                let _ = a.flush().await;
+                a.shutdown().await?;
+            }
+            StreamTxInner::ViaQueue(_) => {
+            }
+            StreamTxInner::ViaFile(_) => {
+            }
+            StreamTxInner::WasmWebSocket(a) => {
+                a.close().await?;
+            }
+        }
+        Ok(())
+    }
+
+    #[allow(unused_variables)]
+    pub async fn write_all(
+        &mut self,
+        buf: &'_ [u8],
+        delay_flush: bool,
+    ) -> Result<(), tokio::io::Error> {
+        #[allow(unused_mut)]
+        match self {
+            #[cfg(feature = "enable_full")]
+            StreamTxInner::Tcp(a) => {
+                a.write_all(buf).await?;
+            }
+            #[cfg(feature = "enable_full")]
+            StreamTxInner::WebSocket(a) => {
                 use futures_util::SinkExt;
-                total_sent += buf.len() as u64;
                 if delay_flush {
                     match a.feed(Message::binary(buf)).await {
                         Ok(a) => a,
@@ -483,9 +560,8 @@ impl StreamTx {
                 }
             }
             #[cfg(feature = "enable_server")]
-            StreamTx::HyperWebSocket(a) => {
+            StreamTxInner::HyperWebSocket(a) => {
                 use futures_util::SinkExt;
-                total_sent += buf.len() as u64;
                 if delay_flush {
                     match a.feed(HyperMessage::binary(buf)).await {
                         Ok(a) => a,
@@ -510,7 +586,7 @@ impl StreamTx {
                     }
                 }
             }
-            StreamTx::ViaStream(a, _) => {
+            StreamTxInner::ViaStream(a) => {
                 use tokio::io::AsyncWriteExt;
                 let mut a = a.lock().await;
                 if buf.len() > u32::MAX as usize {
@@ -524,9 +600,8 @@ impl StreamTx {
                     ));
                 }
                 a.write_all(&buf[..]).await?;
-                total_sent += buf.len() as u64;
             }
-            StreamTx::ViaQueue(a, _) => {
+            StreamTxInner::ViaQueue(a) => {
                 let buf = buf.to_vec();
                 match a.send(buf).await {
                     Ok(a) => a,
@@ -538,49 +613,16 @@ impl StreamTx {
                     }
                 }
             }
-            StreamTx::ViaFile(a, _) => {
+            StreamTxInner::ViaFile(a) => {
                 use std::io::Write;
                 let mut a = a.lock().unwrap();
                 a.write_all(buf)?;
             }
-            #[cfg(target_arch = "wasm32")]
-            StreamTx::WasmWebSocket(a) => {
+            StreamTxInner::WasmWebSocket(a) => {
                 a.send(buf.to_vec()).await?;
             }
         }
-        #[allow(unreachable_code)]
-        Ok(total_sent)
-    }
-
-    #[cfg(feature = "enable_server")]
-    fn conv_error_kind(err: &HyperError) -> tokio::io::ErrorKind {
-        match err {
-            HyperError::AlreadyClosed => tokio::io::ErrorKind::ConnectionAborted,
-            HyperError::ConnectionClosed => tokio::io::ErrorKind::ConnectionAborted,
-            HyperError::Io(io) => io.kind(),
-            _ => tokio::io::ErrorKind::Other,
-        }
-    }
-
-    pub(crate) async fn send(
-        &mut self,
-        wire_encryption: &Option<EncryptKey>,
-        pck: PacketData,
-    ) -> Result<u64, tokio::io::Error> {
-        #[allow(unused_mut)]
-        let mut total_sent = 0u64;
-        match wire_encryption {
-            Some(key) => {
-                let enc = key.encrypt(&pck.bytes[..]);
-                total_sent += self.write_8bit(&enc.iv.bytes, true).await?;
-                total_sent += self.write_32bit(&enc.data, false).await?;
-            }
-            None => {
-                total_sent += self.write_32bit(&pck.bytes[..], false).await?;
-            }
-        };
-        #[allow(unreachable_code)]
-        Ok(total_sent)
+        Ok(())
     }
 }
 
@@ -598,90 +640,31 @@ impl StreamTxChannel {
         }
     }
 
-    pub(crate) async fn send(&mut self, pck: PacketData) -> Result<u64, tokio::io::Error> {
-        self.tx.send(&self.wire_encryption, pck).await
+    pub async fn send(&mut self, data: &[u8]) -> Result<u64, tokio::io::Error> {
+        self.tx.send(&self.wire_encryption, data).await
+    }
+
+    pub async fn close(&mut self) -> Result<(), tokio::io::Error> {
+        self.tx.close().await
     }
 }
 
-impl StreamRx {
-    pub async fn read_8bit(&mut self) -> Result<Vec<u8>, tokio::io::Error> {
-        #[allow(unused_variables)]
-        let ret = match self {
-            #[cfg(feature = "enable_full")]
-            StreamRx::Tcp(a) => {
-                let len = a.read_u8().await?;
-                if len <= 0 {
-                    return Ok(vec![]);
-                }
-                let mut bytes = vec![0 as u8; len as usize];
-                let n = a.read_exact(&mut bytes).await?;
-                if n != (len as usize) {
-                    return Ok(vec![]);
-                }
-                bytes
-            }
-            #[cfg(feature = "enable_full")]
-            StreamRx::WebSocket(_) => self.read_32bit().await?,
-            #[cfg(feature = "enable_server")]
-            StreamRx::HyperWebSocket(_) => self.read_32bit().await?,
-            StreamRx::ViaStream(_, _) => self.read_32bit().await?,
-            StreamRx::ViaQueue(_, _) => self.read_32bit().await?,
-            StreamRx::ViaFile(_, _) => self.read_32bit().await?,
-            #[cfg(target_arch = "wasm32")]
-            StreamRx::WasmWebSocket(_) => self.read_32bit().await?,
-        };
-        #[allow(unreachable_code)]
-        Ok(ret)
-    }
+impl StreamRxInner {
 
-    pub async fn read_16bit(&mut self) -> Result<Vec<u8>, tokio::io::Error> {
+    pub async fn recv(&mut self) -> Result<Vec<u8>, tokio::io::Error> {
         #[allow(unused_variables)]
         let ret = match self {
             #[cfg(feature = "enable_full")]
-            StreamRx::Tcp(a) => {
-                let len = a.read_u16().await?;
-                if len <= 0 {
+            StreamRxInner::Tcp(a) => {
+                let mut bytes = vec![0u8; 4096];
+                let n = a.read(&mut bytes).await?;
+                if n <= 0 {
                     return Ok(vec![]);
                 }
-                let mut bytes = vec![0 as u8; len as usize];
-                let n = a.read_exact(&mut bytes).await?;
-                if n != (len as usize) {
-                    return Ok(vec![]);
-                }
-                bytes
+                bytes[0..n].to_vec()
             }
             #[cfg(feature = "enable_full")]
-            StreamRx::WebSocket(_) => self.read_32bit().await?,
-            #[cfg(feature = "enable_server")]
-            StreamRx::HyperWebSocket(_) => self.read_32bit().await?,
-            StreamRx::ViaStream(_, _) => self.read_32bit().await?,
-            StreamRx::ViaQueue(_, _) => self.read_32bit().await?,
-            StreamRx::ViaFile(_, _) => self.read_32bit().await?,
-            #[cfg(target_arch = "wasm32")]
-            StreamRx::WasmWebSocket(_) => self.read_32bit().await?,
-        };
-        #[allow(unreachable_code)]
-        Ok(ret)
-    }
-
-    pub async fn read_32bit(&mut self) -> Result<Vec<u8>, tokio::io::Error> {
-        #[allow(unused_variables)]
-        let ret = match self {
-            #[cfg(feature = "enable_full")]
-            StreamRx::Tcp(a) => {
-                let len = a.read_u32().await?;
-                if len <= 0 {
-                    return Ok(vec![]);
-                }
-                let mut bytes = vec![0 as u8; len as usize];
-                let n = a.read_exact(&mut bytes).await?;
-                if n != (len as usize) {
-                    return Ok(vec![]);
-                }
-                bytes
-            }
-            #[cfg(feature = "enable_full")]
-            StreamRx::WebSocket(a) => {
+            StreamRxInner::WebSocket(a) => {
                 use futures_util::StreamExt;
                 match a.next().await {
                     Some(a) => {
@@ -713,7 +696,7 @@ impl StreamRx {
                 }
             }
             #[cfg(feature = "enable_server")]
-            StreamRx::HyperWebSocket(a) => {
+            StreamRxInner::HyperWebSocket(a) => {
                 use futures_util::StreamExt;
                 match a.next().await {
                     Some(a) => {
@@ -744,7 +727,7 @@ impl StreamRx {
                     }
                 }
             }
-            StreamRx::ViaStream(a, _) => {
+            StreamRxInner::ViaStream(a) => {
                 use tokio::io::AsyncReadExt;
                 let mut a = a.lock().await;
                 let mut ret = bytes::BytesMut::new();
@@ -759,7 +742,7 @@ impl StreamRx {
                 }
                 ret.to_vec()
             }
-            StreamRx::ViaQueue(a, _) => match a.recv().await {
+            StreamRxInner::ViaQueue(a) => match a.recv().await {
                 Some(a) => a,
                 None => {
                     return Err(tokio::io::Error::new(
@@ -768,7 +751,7 @@ impl StreamRx {
                     ));
                 }
             },
-            StreamRx::ViaFile(a, _) => {
+            StreamRxInner::ViaFile(a) => {
                 use std::io::Read;
                 let mut ret;
                 loop {
@@ -806,8 +789,7 @@ impl StreamRx {
                 }
                 ret
             }
-            #[cfg(target_arch = "wasm32")]
-            StreamRx::WasmWebSocket(a) => match a.recv().await {
+            StreamRxInner::WasmWebSocket(a) => match a.recv().await {
                 Some(a) => a,
                 None => {
                     return Err(tokio::io::Error::new(
@@ -817,24 +799,52 @@ impl StreamRx {
                 }
             },
         };
-        #[allow(unreachable_code)]
         Ok(ret)
     }
+}
+
+#[async_trait::async_trait]
+pub trait StreamReader
+{
+    async fn read_buf_with_header(&mut self, wire_encryption: &Option<EncryptKey>, total_read: &mut u64) -> Result<Vec<u8>, TError>;
+}
+
+impl StreamRx {
+    pub fn new(inner: StreamRxInner, proto: StreamProtocol) -> Self {
+        Self {
+            inner,
+            protocol: proto,
+            version: Box::new(super::protocol::v1::MessageProtocol::default())
+        }
+    }
+
+    pub fn change_protocol_version(&mut self, version: Box<dyn MessageProtocolApi + 'static>) {
+        self.version = version;
+    }
+
+    pub async fn read_with_fixed_16bit_header(&mut self) -> Result<Vec<u8>, tokio::io::Error> {
+        self.version.read_with_fixed_16bit_header(&mut self.inner).await
+    }
+
+    pub async fn read_with_fixed_32bit_header(&mut self) -> Result<Vec<u8>, tokio::io::Error> {
+        self.version.read_with_fixed_32bit_header(&mut self.inner).await
+    }
+
+    pub async fn read_buf_with_header(&mut self, wire_encryption: &Option<EncryptKey>, total_read: &mut u64) -> Result<Vec<u8>, TError> {
+        self.version.read_buf_with_header(&mut self.inner, wire_encryption, total_read).await
+    }
 
     #[allow(dead_code)]
     pub fn protocol(&self) -> StreamProtocol {
-        match self {
-            #[cfg(feature = "enable_full")]
-            StreamRx::Tcp(_) => StreamProtocol::Tcp,
-            #[cfg(feature = "enable_full")]
-            StreamRx::WebSocket(_) => StreamProtocol::WebSocket,
-            #[cfg(feature = "enable_server")]
-            StreamRx::HyperWebSocket(_) => StreamProtocol::WebSocket,
-            StreamRx::ViaStream(_, p) => p.clone(),
-            StreamRx::ViaQueue(_, p) => p.clone(),
-            StreamRx::ViaFile(_, p) => p.clone(),
-            #[cfg(target_arch = "wasm32")]
-            StreamRx::WasmWebSocket(_) => StreamProtocol::WebSocket,
-        }
+        self.protocol.clone()
     }
 }
+
+#[async_trait::async_trait]
+impl StreamReader
+for StreamRx
+{
+    async fn read_buf_with_header(&mut self, wire_encryption: &Option<EncryptKey>, total_read: &mut u64) -> Result<Vec<u8>, TError> {
+        StreamRx::read_buf_with_header(self, wire_encryption, total_read).await
+    }
+}
\ No newline at end of file
