@@ -66,7 +66,8 @@ pub(crate) fn mock_test_mesh(port: u16) -> ConfMesh {
     #[cfg(not(feature = "enable_dns"))]
     roots.push(MeshAddress::new("localhost", port));
 
-    let ret = ConfMesh::new("localhost", roots.iter());
+    let remote = url::Url::parse(format!("{}://localhost", Registry::guess_schema(port)).as_str()).unwrap();
+    let ret = ConfMesh::new("localhost", remote, roots.iter());
     ret
 }
 
