@@ -51,7 +51,13 @@ where
     }
 
     pub fn unwrap(&self, key: &PrivateEncryptKey) -> Result<T, std::io::Error> {
-        let data = key.decrypt(&self.sd_iv, &self.sd_encrypted[..])?;
+        if key.hash() != self.ek_hash {
+            return Err(std::io::Error::new(
+                std::io::ErrorKind::Other,
+                format!("The decryption key is not valid for this cipher data ({} vs {}).", key.hash(), self.ek_hash).as_str(),
+            ));
+        }
+        let data = key.decrypt(&self.sd_iv, &self.sd_encrypted[..]).unwrap();
         Ok(match self.format.deserialize(&data[..]) {
             Ok(a) => a,
             Err(err) => {
@@ -65,6 +71,16 @@ where
     }
 }
 
+impl<T> std::fmt::Display
+for PublicEncryptedSecureData<T>
+where
+    T: serde::Serialize + serde::de::DeserializeOwned
+{
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "secure_data(format={},ek_hash={},size={})", self.format, self.ek_hash, self.sd_encrypted.len())
+    }
+}
+
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct MultiEncryptedSecureData<T>
 where
@@ -203,4 +219,4 @@ where
     pub fn meta_list<'a>(&'a self) -> impl Iterator<Item = &'a String> {
         self.metadata.values()
     }
-}
+}
\ No newline at end of file
