@@ -864,6 +864,18 @@ impl DioMut {
         self.multi.pipe.unlock(key).await
     }
 
+    pub async fn delete_all_roots(self: &Arc<Self>) -> Result<(), CommitError> {
+        self.run_async(self.__delete_all_roots())
+            .await
+    }
+
+    async fn __delete_all_roots(self: &Arc<Self>) -> Result<(), CommitError> {
+        for key in self.__root_keys().await {
+            self.delete(&key).await?;
+        }
+        Ok(())
+    }
+
     pub async fn children<D>(
         self: &Arc<Self>,
         parent_id: PrimaryKey,
@@ -1112,6 +1124,114 @@ impl DioMut {
             .collect::<Vec<_>>())
     }
 
+    pub async fn roots<D>(
+        self: &Arc<Self>,
+    ) -> Result<Vec<DaoMut<D>>, LoadError>
+    where
+        D: Serialize + DeserializeOwned,
+    {
+        self.roots_ext(false, false)
+            .await
+    }
+
+    pub async fn roots_ext<D>(
+        self: &Arc<Self>,
+        allow_missing_keys: bool,
+        allow_serialization_error: bool,
+    ) -> Result<Vec<DaoMut<D>>, LoadError>
+    where
+        D: Serialize + DeserializeOwned,
+    {
+        // Build a list of keys
+        let keys = self.multi.roots_raw().await;
+
+        // Perform the lower level calls
+        let mut ret: Vec<DaoMut<D>> = self
+            .__load_many_ext(
+                keys.into_iter(),
+                allow_missing_keys,
+                allow_serialization_error,
+            )
+            .await?;
+
+        // Build an already loaded list
+        let mut already = FxHashSet::default();
+        for a in ret.iter() {
+            already.insert(a.key().clone());
+        }
+
+        // Now we search the secondary local index so any objects we have
+        // added in this transaction scope are returned
+        let state = self.state.lock().unwrap();
+        let _pop1 = DioMutScope::new(self);
+        for a in state.store_ordered.iter().filter(|a| a.parent.is_none()).map(|a| a.key) {
+            // This is an OR of two lists so its likely that the object
+            // may already be in the return list
+            if already.contains(&a) {
+                continue;
+            }
+            if state.deleted.contains(&a) {
+                continue;
+            }
+
+            // If its still locked then that is a problem
+            if state.is_locked(&a) {
+                bail!(LoadErrorKind::ObjectStillLocked(a.clone()));
+            }
+
+            if let Some(dao) = state.rows.get(&a) {
+                let (row_header, row) = Row::from_row_data(&self.dio, dao.deref())?;
+
+                already.insert(row.key.clone());
+                let dao: Dao<D> = Dao::new(&self.dio, row_header, row);
+                ret.push(DaoMut::new(Arc::clone(self), dao));
+            }
+        }
+
+        Ok(ret)
+    }
+
+    pub async fn root_keys(
+        self: &Arc<Self>,
+    ) -> Vec<PrimaryKey>
+    {
+        self.run_async(self.__root_keys())
+            .await
+    }
+
+    async fn __root_keys(
+        self: &Arc<Self>,
+    ) -> Vec<PrimaryKey>
+    {
+        // Build a list of keys
+        let keys = self.multi
+            .roots_raw()
+            .await;
+
+        // Remove anythign thats deleted and return it
+        let state = self.state.lock().unwrap();
+        let mut ret: Vec<PrimaryKey> = keys.into_iter()
+            .filter(|k| state.deleted.contains(k))
+            .collect();
+
+        // Build an already loaded list
+        let mut already = FxHashSet::default();
+        for a in ret.iter() {
+            already.insert(a.clone());
+        }
+
+        for a in state.store_ordered.iter().filter(|a| a.parent.is_none()).map(|a| a.key) {
+            if already.contains(&a) {
+                continue;
+            }
+            if state.deleted.contains(&a) {
+                continue;
+            }
+            ret.push(a);
+        }
+        ret
+    }
+
     pub(crate) fn data_as_overlay(
         self: &Arc<Self>,
         session: &'_ dyn AteSession,
@@ -1128,4 +1248,8 @@ impl DioMut {
     pub fn session_mut<'a>(&'a self) -> DioSessionGuardMut<'a> {
         self.dio.session_mut()
     }
+
+    pub fn remote<'a>(&'a self) -> Option<&'a url::Url> {
+        self.dio.remote()
+    }
 }
