@@ -94,6 +94,16 @@ where
     pub format: MessageFormat,
 }
 
+impl std::fmt::Display for EventData {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        if let Some(data) = &self.data_bytes {
+            write!(f, "format={}, meta={}, data={}", self.format, self.meta, data.len())
+        } else {
+            write!(f, "format={}, meta={}", self.format, self.meta)
+        }
+    }
+}
+
 impl EventData {
     #[allow(dead_code)]
     pub(crate) fn new(key: PrimaryKey, data: Bytes, format: MessageFormat) -> EventData {
