@@ -1,14 +1,13 @@
-#[allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
-use crate::{event::*, redo::LogLookup};
 use crate::index::*;
+use crate::{event::*, redo::LogLookup};
+#[allow(unused_imports)]
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 
 #[derive(Debug, Clone)]
-pub struct LoadResult
-{
+pub struct LoadResult {
     #[allow(dead_code)]
     pub(crate) lookup: LogLookup,
     pub header: EventHeaderRaw,
     pub data: EventData,
     pub leaf: EventLeaf,
-}
\ No newline at end of file
+}
